<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * After records are relieved from database each field has a chance to transform the data.
 *
 * @package     mod_videotime
 * @copyright   2020 bdecent gmbh <https://bdecent.de>
 * @license     http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace mod_videotime\local\block_dash\attribute;

use block_dash\local\data_grid\field\attribute\abstract_field_attribute;
use mod_videotime\videotime_instance;

/**
 * Transforms data to formatted video time notes.
 *
 * @package mod_videotime
 */
class video_created_attribute extends abstract_field_attribute {
    /**
     * After records are relieved from database each field has a chance to transform the data.
     * Example: Convert unix timestamp into a human readable date format
     *
     * @param int $data
     * @param \stdClass $record Entire row
     * @return mixed
     * @throws \moodle_exception
     */
    public function transform_data($data, \stdClass $record) {
        global $DB;

        $instance = videotime_instance::instance_by_id($data);

        if ($videorecord = $DB->get_record('videotime_vimeo_video', ['link' => $instance->vimeo_url])) {
            $video = \videotimeplugin_repository\video::create($videorecord, $instance->get_context());
            if (
                $createdtime = \DateTime::createFromFormat(
                    \DateTime::ISO8601,
                    $video->get_record()->created_time ?? '',
                    new \DateTimeZone('UTC')
                )
            ) {
                $createdtime->setTimezone(\core_date::get_user_timezone_object());
                return $createdtime->getTimestamp();
            }
        }

        return null;
    }
}
